Flag

Trait Flag 

pub trait Flag {
    // Required method
    fn get_offset(&self) -> u8;
}
Allows a value to be represented as a bit flag

Required Methods

fn get_offset(&self) -> u8

Returns the value’s bit flag offset

This is used as a shift offset, so it should not be greater than or equal to the total number of bits within the field

Implementors